#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-objectorientation
version:              2.3.1
visibility:           public
id:                   hslua-objectorientation-2.3.1-2zJu8nKSSdxCUQNnxyfl9u
key:                  hslua-objectorientation-2.3.1-2zJu8nKSSdxCUQNnxyfl9u
license:              MIT
copyright:            © 2021-2024 Albert Krewinkel
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Object orientation tools for HsLua
description:
    Expose Haskell objects to Lua with an object oriented
    interface.

category:             Foreign
abi:                  8e6235a5b59e8bd8614960cbed6b90a5
exposed:              True
exposed-modules:
    HsLua.ObjectOrientation HsLua.ObjectOrientation.Operation

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hslua-objectorientation-2.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hslua-objectorientation-2.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hslua-objectorientation-2.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-objectorientation
hs-libraries:         HShslua-objectorientation-2.3.1-2zJu8nKSSdxCUQNnxyfl9u
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    exceptions-0.10.7 hslua-core-2.3.2.1-3tsNfZ2PPMpIrGoJYp3SDj
    hslua-marshalling-2.3.2-EQCZTvqDYkhHetwO8kOojF
    hslua-typing-0.1.1-AicHKRlaLWcJSxT7T71kDy mtl-2.3.1 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-objectorientation/html/hslua-objectorientation.haddock

haddock-html:         /usr/share/doc/haskell-hslua-objectorientation/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

